@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 sub new {
     my $class = shift;
@@ -246,14 +246,34 @@ takes no arguments.
 =head2 include
 
 Processes B<Include> and B<IncludeOptional> statements and replaces them
-with the contents of the files supplied in their arguments. If the argument
+with the contents of the files supplied in their argument. If the latter
 is not an absolute file name, it is searched in the server root directory.
-The latter is determined inspecting the B<ServerRoot> statement. If this
-statement is absent, the current working directory is used. The
-B<-server_root> constructor argument can be used to enforce a specific
-server root directory, e.g.
 
-    -expand => [ { include => { -server_root => '/etc/httpd/conf' } } ]
+The following keyword arguments can be used to set the default server root
+directory:
+
+=over 4
+
+=item B<server_root =E<gt>> I<DIR>
+
+Sets default server root value to I<DIR>.
+
+=item B<probe =E<gt>> I<LISTREF> | B<1>
+
+Determines the default server root value by analyzing the output of
+B<httpd -V>. If I<LISTREF> is given, it contains alternative pathnames
+of the Apache B<httpd> binary. Otherwise, 
+
+    probe => 1
+
+is a shorthand for
+
+    probe => [qw(/usr/sbin/httpd /usr/sbin/apache2)]
+        
+=back
+
+When the B<ServerRoot> statement is seen, its value overwrites any
+previously set server root directory. 
 
 =head2 ifmodule
 
